<?php

declare(strict_types=1);

/**
 * @author Amasty Team
 * @copyright Copyright (c) Amasty (https://www.amasty.com)
 * @package Shop By Brand Widget
 */

namespace Amasty\ShopByBrandWidget\Model\Source;

use Amasty\ShopbyBrand\Model\Brand\ListDataProvider\LoadItems;
use Magento\Framework\Data\OptionSourceInterface;
use Magento\Store\Model\Store;
use Magento\Store\Model\StoreManagerInterface;

class HidedBrands implements OptionSourceInterface
{
    /**
     * @var LoadItems
     */
    private $loadItems;

    /**
     * @var StoreManagerInterface
     */
    private $storeManager;

    public function __construct(
        LoadItems $loadItems,
        StoreManagerInterface $storeManager
    ) {
        $this->loadItems = $loadItems;
        $this->storeManager = $storeManager;
    }

    public function toOptionArray(): array
    {
        $optionArray = [];
        $stores = $this->storeManager->getStores(true);
        foreach ($stores as $store) {
            $brandOptions = $this->loadItems->getItems((int)$store->getId());

            foreach ($brandOptions as $option) {
                $brandId = $option->getBrandId();
                if (!isset($optionArray[$brandId])) {
                    $optionArray[$brandId] = [
                        'value' => $brandId,
                        'label' => $option->getLabel()
                    ];
                }
            }
        }

        return $optionArray;
    }
}
